@@ -1,32 +1,46 @@
-use 5.008001;
 use strict;
 use warnings;
 
 package Dancer2::Session::Memcached;
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Dancer 2 session storage with Cache::Memcached
-# VERSION
-our $VERSION = '0.004';
-
-use Carp;
+$Dancer2::Session::Memcached::VERSION = '0.005';
 use Moo;
 use Cache::Memcached;
-use Dancer2::Core::Types;
+
+use Types::Standard qw/ Str ArrayRef InstanceOf /;
+
+use Type::Tiny;
+
+my $Server = Type::Tiny->new(
+    name       => 'MemcachedServer',
+    parent     => Str,
+    constraint => sub { ! /^\d+\.\d+\.\d+\.\d+$/ },
+    message    => sub {
+        "server `$_' is invalid; port is missing, use `server:port'"
+    },
+
+);
+
+my $Servers = Type::Tiny->new(
+    name     => 'MemcachedServers',
+    parent   => ArrayRef[$Server],
+    coercion => Type::Coercion->new( type_coercion_map => [
+        Str ,=> sub { [ split ',', $_ ] },
+    ]),
+);
+
 
 #--------------------------------------------------------------------------#
 # Public attributes
 #--------------------------------------------------------------------------#
 
-#pod =attr memcached_servers (required)
-#pod
-#pod A comma-separated list of reachable memcached servers (can be either
-#pod address:port or socket paths).
-#pod
-#pod =cut
 
 has memcached_servers => (
     is       => 'ro',
-    isa      => Str,
+    isa      => $Servers,
     required => 1,
+    coerce   => $Servers->coercion,
 );
 
 #--------------------------------------------------------------------------#
@@ -38,30 +52,15 @@ has _memcached => (
     isa => InstanceOf ['Cache::Memcached'],
     handles => {
         _retrieve => 'get',
-        _flush => 'set',
-        _destroy => 'delete',
+        _flush    => 'set',
+        _destroy  => 'delete',
     },
 );
 
 # Adapted from Dancer::Session::Memcached
 sub _build__memcached {
     my ($self) = @_;
-
-    my $servers = $self->memcached_servers;
-
-    croak "The setting memcached_servers must be defined"
-      unless defined $servers;
-
-    $servers = [ split /,\s*/, $servers ];
-
-    # make sure the servers look good
-    foreach my $s (@$servers) {
-        if ( $s =~ /^\d+\.\d+\.\d+\.\d+$/ ) {
-            croak "server `$s' is invalid; port is missing, use `server:port'";
-        }
-    }
-
-    return Cache::Memcached->new( servers => $servers );
+    return Cache::Memcached->new( servers => $self->memcached_servers );
 }
 
 #--------------------------------------------------------------------------#
@@ -74,10 +73,7 @@ with 'Dancer2::Core::Role::SessionFactory';
 
 # memcached doesn't have any easy way to list keys it knows about
 # so we cheat and return an empty array ref
-sub _sessions {
-    my ($self) = @_;
-    return [];
-}
+sub _sessions { [] }
 
 sub _change_id {
     my ( $self, $old_id, $new_id ) = @_;
@@ -102,7 +98,7 @@ Dancer2::Session::Memcached - Dancer 2 session storage with Cache::Memcached
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -112,61 +108,29 @@ version 0.004
   engines:
     session:
       Memcached:
-        memcached_servers: 10.0.1.31:11211,10.0.1.32:11211,/var/sock/memcached
+        memcached_servers: 
+          - 10.0.1.31:11211
+          - 10.0.1.32:11211
+          - /var/sock/memcached
 
 =head1 DESCRIPTION
 
-This module implements a session factory for Dancer 2 that stores session
+This module implements a session factory for L<Dancer2> that stores session
 state within Memcached using L<Cache::Memcached>.
 
 =head1 ATTRIBUTES
 
 =head2 memcached_servers (required)
 
-A comma-separated list of reachable memcached servers (can be either
-address:port or socket paths).
+An array (or a comma-separated list) of reachable memcached 
+servers (can be either address:port or socket paths).
 
 =for Pod::Coverage method_names_here
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/PerlDancer/dancer2-session-memcached/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/PerlDancer/dancer2-session-memcached>
-
-  git clone https://github.com/PerlDancer/dancer2-session-memcached.git
-
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTORS
-
-=for stopwords Peter Mottram Yanick Champoux
-
-=over 4
-
-=item *
-
-Peter Mottram <peter@sysnix.com>
-
-=item *
-
-Yanick Champoux <yanick@babyl.dyndns.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
